@@ -2,7 +2,7 @@
  * pg_wait_sampling.h
  *		Headers for pg_wait_sampling extension.
  *
- * Copyright (c) 2015-2016, Postgres Professional
+ * Copyright (c) 2015-2025, Postgres Professional
  *
  * IDENTIFICATION
  *	  contrib/pg_wait_sampling/pg_wait_sampling.h
@@ -10,11 +10,10 @@
 #ifndef __PG_WAIT_SAMPLING_H__
 #define __PG_WAIT_SAMPLING_H__
 
-#include "postgres.h"
-
-#include "storage/proc.h"
+#include "datatype/timestamp.h"
+#include "storage/latch.h"
+#include "storage/lock.h"
 #include "storage/shm_mq.h"
-#include "utils/timestamp.h"
 
 #define	PG_WAIT_SAMPLING_MAGIC		0xCA94B107
 #define COLLECTOR_QUEUE_SIZE		(16 * 1024)
@@ -24,26 +23,26 @@
 
 typedef struct
 {
-	int				pid;
-	uint32			wait_event_info;
-	uint64			queryId;
-	uint64			count;
+	int			pid;
+	uint32		wait_event_info;
+	uint64		queryId;
+	uint64		count;
 } ProfileItem;
 
 typedef struct
 {
-	int				pid;
-	uint32			wait_event_info;
-	uint64			queryId;
-	TimestampTz		ts;
+	int			pid;
+	uint32		wait_event_info;
+	uint64		queryId;
+	TimestampTz ts;
 } HistoryItem;
 
 typedef struct
 {
-	bool			wraparound;
-	Size			index;
-	Size			count;
-	HistoryItem	   *items;
+	bool		wraparound;
+	Size		index;
+	Size		count;
+	HistoryItem *items;
 } History;
 
 typedef enum
@@ -56,22 +55,22 @@ typedef enum
 
 typedef struct
 {
-	Latch		   *latch;
-	SHMRequest		request;
+	Latch	   *latch;
+	SHMRequest	request;
 } CollectorShmqHeader;
 
 /* GUC variables */
-extern int pgws_historySize;
-extern int pgws_historyPeriod;
-extern int pgws_profilePeriod;
+extern int	pgws_historySize;
+extern int	pgws_historyPeriod;
+extern int	pgws_profilePeriod;
 extern bool pgws_profilePid;
-extern int pgws_profileQueries;
+extern int	pgws_profileQueries;
 extern bool pgws_sampleCpu;
 
 /* pg_wait_sampling.c */
 extern CollectorShmqHeader *pgws_collector_hdr;
-extern shm_mq			   *pgws_collector_mq;
-extern uint64			   *pgws_proc_queryids;
+extern shm_mq *pgws_collector_mq;
+extern uint64 *pgws_proc_queryids;
 extern void pgws_init_lock_tag(LOCKTAG *tag, uint32 lock);
 extern bool pgws_should_sample_proc(PGPROC *proc, int *pid_p, uint32 *wait_event_info_p);
 
